@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006 k.watanabe
+ * Copyright (C) 2006-2007 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.12 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.13 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -72,9 +72,9 @@ define('SYL_CONFIG_CONTROLLER_NAME', 'controller');
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Controller.php,v 1.12 2007/01/15 15:55:12 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Controller.php,v 1.13 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Controller
@@ -138,31 +138,6 @@ class SyL_Controller
      */
     var $container = null;
 
-    /**
-     * ȥ
-     *
-     * ¹ԴĶˤꡢWEB or CmdΥȥȽꤷƼ
-     *
-     * @access public
-     * @param array Ķ
-     */
-    function &getController($config=array())
-    {
-        static $singleton;
-        if (!is_object($singleton)) {
-            if ((PHP_SAPI == 'cli') || ((PHP_SAPI == 'cgi') && !isset($_SERVER['REQUEST_METHOD']))) {
-                define('SYL_ENV_TYPE', 'cmd');
-            } else {
-                define('SYL_ENV_TYPE', 'web');
-            }
-            $class_name = 'SyL_Controller' . ucfirst(SYL_ENV_TYPE);
-            include_once SYL_INCLUDE_DIR . "/framework/Controller/{$class_name}.php";
-            // ҥ饹Υ󥹥
-            $singleton = new $class_name($config);
-        }
-        return $singleton;
-    }
-
     /**
      * 󥹥ȥ饯
      *
@@ -211,6 +186,35 @@ class SyL_Controller
         }
     }
 
+    /**
+     * ȥ
+     *
+     * ¹ԴĶˤꡢWEB or CmdΥȥȽꤷƼ
+     *
+     * @access public
+     * @param array Ķ
+     */
+    function &getController($config=array())
+    {
+        static $singleton;
+        if (!is_object($singleton)) {
+            if (isset($config['type']) && $config['type']) {
+                define('SYL_ENV_TYPE', $config['type']);
+            } else {
+                if ((PHP_SAPI == 'cli') || ((PHP_SAPI == 'cgi') && !isset($_SERVER['REQUEST_METHOD']))) {
+                    define('SYL_ENV_TYPE', 'cmd');
+                } else {
+                    define('SYL_ENV_TYPE', 'web');
+                }
+            }
+            $class_name = 'SyL_Controller' . ucfirst(SYL_ENV_TYPE);
+            include_once SYL_INCLUDE_DIR . "/framework/Controller/{$class_name}.php";
+            // ҥ饹Υ󥹥
+            $singleton = new $class_name($config);
+        }
+        return $singleton;
+    }
+
     /**
      * 
      *
