@@ -6,7 +6,7 @@
  *
  * PHP version 4 (>= 4.3.x) or 5
  *
- * Copyright (C) 2006 k.watanabe
+ * Copyright (C) 2006-2007 k.watanabe
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,9 @@
  * -----------------------------------------------------------------------------
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.3 2007/01/03 11:17:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.4 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -37,65 +37,13 @@
  *
  * @package   SyL
  * @author    k.watanabe <k.watanabe@syl.jp>
- * @copyright 2006 k.watanabe
+ * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_Response.php,v 1.3 2007/01/03 11:17:37 seasonstream Exp $
+ * @version   CVS: $Id: SyL_Response.php,v 1.4 2007/01/21 08:12:34 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_Response
 {
-    /**
-     * HTTP쥹ݥ󥹥ơ
-     * 
-     * @access public
-     * @var array
-     */
-/*
-    var $status_codes = array(
-      '100' => 'Continue',
-      '101' => 'Switching Protocols',
-      '200' => 'OK',
-      '201' => 'Created',
-      '202' => 'Accepted',
-      '203' => 'Non-Authoritative Information',
-      '204' => 'No Content',
-      '205' => 'Reset Content',
-      '206' => 'Partial Content',
-      '300' => 'Multiple Choices',
-      '301' => 'Moved Permanently',
-      '302' => 'Found',
-      '303' => 'See Other',
-      '304' => 'Not Modified',
-      '305' => 'Use Proxy',
-      '306' => '(Unused)',
-      '307' => 'Temporary Redirect',
-      '400' => 'Bad Request',
-      '401' => 'Unauthorized',
-      '402' => 'Payment Required',
-      '403' => 'Forbidden',
-      '404' => 'Not Found',
-      '405' => 'Method Not Allowed',
-      '406' => 'Not Acceptable',
-      '407' => 'Proxy Authentication Required',
-      '408' => 'Request Timeout',
-      '409' => 'Conflict',
-      '410' => 'Gone',
-      '411' => 'Length Required',
-      '412' => 'Precondition Failed',
-      '413' => 'Request Entity Too Large',
-      '414' => 'Request-URI Too Long',
-      '415' => 'Unsupported Media Type',
-      '416' => 'Requested Range Not Satisfiable',
-      '417' => 'Expectation Failed',
-      '500' => 'Internal Server Error',
-      '501' => 'Not Implemented',
-      '502' => 'Bad Gateway',
-      '503' => 'Service Unavailable',
-      '504' => 'Gateway Timeout',
-      '505' => 'HTTP Version Not Supported'
-    );
-*/
-
     /**
      * ɲHTTP쥹ݥ󥹥إå
      * 
@@ -146,7 +94,7 @@ class SyL_Response
         $request_uri = isset($_SERVER['REQUEST_URI']) ? $_SERVER['REQUEST_URI'] : '';
         SyL_Loggers::info("[Response] 404 Not Found - {$request_uri}");
 
-        SyL_Response::setHeader('HTTP/1.0 404 Not Found');
+        SyL_Response::setStatusHeader('404');
         if (defined('SYL_RESPONSE_URL_404') && SYL_RESPONSE_URL_404) {
             SyL_Response::redirect(SYL_RESPONSE_URL_404);
         } else {
@@ -169,6 +117,20 @@ class SyL_Response
         $obj->headers[$name] = $value;
     }
 
+    /**
+     * HTTP쥹ݥ󥹥ơإå򥻥åȤ
+     * 
+     * @static
+     * @access public
+     * @param string ơ
+     * @param string إå
+     */
+    function setStatusHeader($status_code)
+    {
+        $status_header = SyL_Response::getStatusHeader($status_code);
+        SyL_Response::setHeader($status_header);
+    }
+
     /**
      * HTTP쥹ݥ󥹥إå
      * 
@@ -237,14 +199,14 @@ class SyL_Response
      * 󥰤줿HTML
      * 
      * @access public
-     * @param object ӥ塼֥
+     * @param mixed ӥ塼֥ȡޤɽǡ
      */
     function display(&$view)
     {
         // إå
         $this->sendHeader();
-        // HTML
-        echo $view->getRender();
+        // ɽǡ
+        echo is_object($view) ? $view->getRender() : $view;
 
         // Хåե󥰽
         $neste = ob_get_level();
@@ -252,6 +214,66 @@ class SyL_Response
             ob_end_flush();
         }
     }
+
+    /**
+     * ơɤ饹ơإå
+     * 
+     * @static
+     * @access public
+     * @param string ơ
+     * @param string HTTPС
+     * @return string ơإå
+     */
+    function getStatusHeader($status_code, $http_version='1.0')
+    {
+        $message = '';
+        switch ($status_code) {
+        case '100': $message = 'Continue'; break;
+        case '101': $message = 'Switching Protocols'; break;
+        case '200': $message = 'OK'; break;
+        case '201': $message = 'Created'; break;
+        case '202': $message = 'Accepted'; break;
+        case '203': $message = 'Non-Authoritative Information'; break;
+        case '204': $message = 'No Content'; break;
+        case '205': $message = 'Reset Content'; break;
+        case '206': $message = 'Partial Content'; break;
+        case '300': $message = 'Multiple Choices'; break;
+        case '301': $message = 'Moved Permanently'; break;
+        case '302': $message = 'Found'; break;
+        case '303': $message = 'See Other'; break;
+        case '304': $message = 'Not Modified'; break;
+        case '305': $message = 'Use Proxy'; break;
+        case '306': $message = '(Unused)'; break;
+        case '307': $message = 'Temporary Redirect'; break;
+        case '400': $message = 'Bad Request'; break;
+        case '401': $message = 'Unauthorized'; break;
+        case '402': $message = 'Payment Required'; break;
+        case '403': $message = 'Forbidden'; break;
+        case '404': $message = 'Not Found'; break;
+        case '405': $message = 'Method Not Allowed'; break;
+        case '406': $message = 'Not Acceptable'; break;
+        case '407': $message = 'Proxy Authentication Required'; break;
+        case '408': $message = 'Request Timeout'; break;
+        case '409': $message = 'Conflict'; break;
+        case '410': $message = 'Gone'; break;
+        case '411': $message = 'Length Required'; break;
+        case '412': $message = 'Precondition Failed'; break;
+        case '413': $message = 'Request Entity Too Large'; break;
+        case '414': $message = 'Request-URI Too Long'; break;
+        case '415': $message = 'Unsupported Media Type'; break;
+        case '416': $message = 'Requested Range Not Satisfiable'; break;
+        case '417': $message = 'Expectation Failed'; break;
+        case '500': $message = 'Internal Server Error'; break;
+        case '501': $message = 'Not Implemented'; break;
+        case '502': $message = 'Bad Gateway'; break;
+        case '503': $message = 'Service Unavailable'; break;
+        case '504': $message = 'Gateway Timeout'; break;
+        case '505': $message = 'HTTP Version Not Supported'; break;
+        default   : return false;
+        }
+
+        return "HTTP/{$http_version} {$message}";
+    }
 }
 
 ?>
