@@ -27,7 +27,7 @@
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.10 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.11 2007/01/28 07:12:48 seasonstream Exp $
  * @link      http://www.syl.jp/
  * -----------------------------------------------------------------------------
  */
@@ -44,7 +44,7 @@ require_once SYL_INCLUDE_DIR . '/framework/SyL_Config.php';
  * @author    k.watanabe <k.watanabe@syl.jp>
  * @copyright 2006-2007 k.watanabe
  * @license   http://www.opensource.org/licenses/lgpl-license.php
- * @version   CVS: $Id: SyL_View.php,v 1.10 2007/01/21 08:12:34 seasonstream Exp $
+ * @version   CVS: $Id: SyL_View.php,v 1.11 2007/01/28 07:12:48 seasonstream Exp $
  * @link      http://www.syl.jp/
  */
 class SyL_View
@@ -130,7 +130,7 @@ class SyL_View
                 $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
                 break;
             case 'json':
-                $class_name = 'SyL_ViewJson';
+                $class_name = 'SyL_ViewJsJson';
                 $class_file = SYL_INCLUDE_DIR . "/framework/View/{$class_name}.php";
                 break;
             case 'default':
